summaryrefslogtreecommitdiff
path: root/Build
diff options
context:
space:
mode:
authorKarl Berry <karl@freefriends.org>2007-09-09 22:51:23 +0000
committerKarl Berry <karl@freefriends.org>2007-09-09 22:51:23 +0000
commit67db54aa1c5ee5016d3ecadb1b436cc1b8d41d33 (patch)
treeaede7465460075d4c66e6c3ae54ff57768824d62 /Build
parentd112d1b7efe434750ca255fe2f0e191e8ba8f2f7 (diff)
TEXMFVAR (from Akira)
git-svn-id: svn://tug.org/texlive/trunk@4927 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Build')
-rw-r--r--Build/source/texk/tetex/updmap.pl12
1 files changed, 6 insertions, 6 deletions
diff --git a/Build/source/texk/tetex/updmap.pl b/Build/source/texk/tetex/updmap.pl
index 58b29af6f78..e3b9e9b0139 100644
--- a/Build/source/texk/tetex/updmap.pl
+++ b/Build/source/texk/tetex/updmap.pl
@@ -55,7 +55,7 @@ my $opt_edit;
my $opt_help;
my $TEXMFMAIN;
-my $VARTEXMF;
+my $TEXMFVAR;
my $mode;
my $dvipsPreferOutline;
@@ -695,7 +695,7 @@ sub showOptions {
###############################################################################
# setupDestDir()
# find an output directory if none specified on cmd line. First choice is
# $VARTEXMF/fonts/map/updmap (if VARTEXMF is set), next is relative to
# config file location. Fallback is $TEXMFMAIN/fonts/map/updmap.
###############################################################################
sub setupOutputDir {
@@ -704,15 +704,15 @@ sub setupOutputDir {
if (!$od) {
my $rel = "fonts/map/$driver/updmap";
# Try VARTEXMF tree. Use it if variable is set and $rel can
# be written. Copy config file if it does not exist there.
- my $tf = `kpsewhich -expand-var="\$VARTEXMF"`;
+ my $tf = `kpsewhich -expand-var="\$TEXMFVAR"`;
chomp($tf);
if ($tf) {
mkpath("$tf/$rel");
# system("$TEXMFMAIN/web2c/mktexdir \"$tf/$rel\"");
if (! -d "$tf/$rel" || ! -w "$tf/$rel") {
# forget about VARTEXMF tree...
$tf = "";
}
}
@@ -757,7 +757,7 @@ sub setupDestDir {
sub setupCfgFile {
if (! $cnfFile) {
- my $tf = `kpsewhich -expand-var="\$VARTEXMF"`;
+ my $tf = `kpsewhich -expand-var="\$TEXMFVAR"`;
chomp($tf);
if ($tf && ! -f "$tf/web2c/$cnfFileShort") {
mkpath("$tf/web2c") if (! -d "$tf/web2c");
@@ -695,7 +695,7 @@ sub showOptions {
# setupDestDir()
# find an output directory if none specified on cmd line. First choice is
-# $VARTEXMF/fonts/map/updmap (if VARTEXMF is set), next is relative to
+# $TEXMFVAR/fonts/map/updmap (if TEXMFVAR is set), next is relative to
# config file location. Fallback is $TEXMFMAIN/fonts/map/updmap.
###############################################################################
@@ -704,15 +704,15 @@ sub setupOutputDir {
if (!$od) {
my $rel = "fonts/map/$driver/updmap";
- # Try VARTEXMF tree. Use it if variable is set and $rel can
+ # Try TEXMFVAR tree. Use it if variable is set and $rel can
# be written. Copy config file if it does not exist there.
@@ -704,15 +704,15 @@ sub setupOutputDir {
# system("$TEXMFMAIN/web2c/mktexdir \"$tf/$rel\"");
if (! -d "$tf/$rel" || ! -w "$tf/$rel") {
- # forget about VARTEXMF tree...
+ # forget about TEXMFVAR tree...
$tf = "";
}